@@ -1,7 +1,7 @@
 package Perinci::Access::Lite;
 
-our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-07-10'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,6 +30,8 @@ sub __package_exists {
 }
 
 sub request {
+    no strict 'refs';
+
     my ($self, $action, $url, $extra) = @_;
 
     #say "D:request($action => $url)";
@@ -45,11 +47,12 @@ sub request {
     if ($url =~ m!\A(?:pl:)?/(\w+(?:/\w+)*)/(\w*)\z!) {
         my ($modpath, $func) = ($1, $2);
         (my $pkg = $modpath) =~ s!/!::!g;
-        #say "D:modpath=$modpath, pkg=$pkg, package exists? ", __package_exists($pkg);
-        # skip loading module if package already exists, e.g. 'main' (there is
-        # no corresponding module) or packages from loaded modules
         my $pkg_exists = __package_exists($pkg);
-        unless ($pkg_exists) {
+      LOAD:
+        {
+            # special names
+            last LOAD if $pkg =~ /\A(main)\z/;
+            last if $pkg_exists && defined(${"$pkg\::VERSION"});
             #say "D:Loading $pkg ...";
             eval { require "$modpath.pm" };
             return [500, "Can't load module $pkg: $@"] if $@;
@@ -202,7 +205,7 @@ Perinci::Access::Lite - A lightweight Riap client library
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-01-22.
+This document describes version 0.10 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-07-10.
 
 =head1 DESCRIPTION
 
